@@ -46,10 +46,15 @@ __all__ = (
     "AchievementProgress",
     "Activities",
     "Activity",
+    "ActivityGains",
+    "ActivityLeader",
     "BaseEnum",
-    "Boss",
-    "Bosses",
     "BaseModel",
+    "BaseService",
+    "Boss",
+    "BossGains",
+    "BossLeader",
+    "Bosses",
     "Client",
     "Country",
     "Competition",
@@ -58,13 +63,18 @@ __all__ = (
     "CompetitionParticipationDetail",
     "CompetitionParticipation",
     "CompetitionProgress",
+    "CompetitionService",
     "CompetitionStatus",
     "CompetitionType",
     "CompetitionWithParticipations",
     "CompiledRoute",
+    "ComputedGains",
     "ComputedMetric",
+    "ComputedMetricLeader",
     "ComputedMetrics",
     "DeltaLeaderboardEntry",
+    "DeltaService",
+    "EfficiencyService",
     "Err",
     "Gains",
     "GroupDetail",
@@ -77,14 +87,18 @@ __all__ = (
     "GroupMembership",
     "Group",
     "GroupRole",
+    "GroupService",
     "GroupStatistics",
     "HttpErrorResponse",
+    "HttpService",
     "HttpSuccessResponse",
     "Membership",
     "Metric",
+    "MetricLeaders",
     "NameChangeData",
     "NameChangeDetail",
     "NameChange",
+    "NameChangeService",
     "NameChangeStatus",
     "Ok",
     "Participation",
@@ -92,21 +106,27 @@ __all__ = (
     "PlayerAchievementProgress",
     "PlayerBuild",
     "PlayerCompetitionStanding",
+    "PlayerGains",
+    "PlayerGainsData",
     "PlayerMembership",
     "Player",
     "PlayerDetail",
     "PlayerParticipation",
+    "PlayerService",
+    "PlayerStatus",
     "PlayerType",
     "Record",
+    "RecordService",
     "RecordLeaderboardEntry",
     "Result",
     "Route",
     "Serializer",
     "Skill",
+    "SkillGains",
+    "SkillLeader",
     "Skills",
     "SnapshotData",
     "Snapshot",
-    "StatisticsSnapshot",
     "Team",
     "Top5ProgressResult",
     "UnwrapError",
@@ -114,7 +134,7 @@ __all__ = (
 )
 
 __packagename__: Final[str] = "wom.py"
-__version__: Final[str] = "0.1.1"
+__version__: Final[str] = "0.3.0"
 __author__: Final[str] = "Jonxslays"
 __copyright__: Final[str] = "2023-present Jonxslays"
 __description__: Final[str] = "An asynchronous wrapper for the Wise Old Man API."
@@ -122,7 +142,7 @@ __url__: Final[str] = "https://github.com/Jonxslays/wom.py"
 __docs__: Final[str] = "https://jonxslays.github.io/wom.py"
 __repository__: Final[str] = __url__
 __license__: Final[str] = "MIT"
-__git_sha__: Final[str] = "[db13d54]"
+__git_sha__: Final[str] = "[7403fdf]"
 
 from . import client
 from . import constants
