@@ -36,6 +36,21 @@ __all__ = ("Serializer",)
 T = t.TypeVar("T")
 TransformT = t.Callable[[t.Any], t.Any] | None
 AchievementT = t.TypeVar("AchievementT", models.Achievement, models.AchievementProgress)
+HasMetricsT = t.TypeVar(
+    "HasMetricsT",
+    models.Skill,
+    models.Boss,
+    models.Activity,
+    models.ComputedMetric,
+    models.SkillLeader,
+    models.BossLeader,
+    models.ActivityLeader,
+    models.ComputedMetricLeader,
+    models.SkillGains,
+    models.BossGains,
+    models.ActivityGains,
+    models.ComputedGains,
+)
 
 
 class Serializer:
@@ -53,6 +68,11 @@ class Serializer:
         first, *rest = attr.split("_")
         return "".join((first.lower(), *map(str.title, rest)))
 
+    def __map(
+        self, serializer: t.Callable[[dict[str, t.Any]], HasMetricsT], data: list[dict[str, t.Any]]
+    ) -> dict[t.Any, HasMetricsT]:
+        return {x.metric: x for x in (serializer(y) for y in data)}
+
     def _set_attrs(
         self,
         model: t.Any,
@@ -124,7 +144,6 @@ class Serializer:
             "id",
             "username",
             "display_name",
-            "flagged",
             "exp",
             "ehp",
             "ehb",
@@ -134,6 +153,7 @@ class Serializer:
 
         player.type = models.PlayerType.from_str(data["type"])
         player.build = models.PlayerBuild.from_str(data["build"])
+        player.status = models.PlayerStatus.from_str(data["status"])
         player.country = models.Country.from_str_maybe(data["country"])
         player.registered_at = self._dt_from_iso(data["registeredAt"])
         player.updated_at = self._dt_from_iso(data["updatedAt"])
@@ -172,37 +192,6 @@ class Serializer:
         self._set_attrs_cased(snapshot, data, "id", "player_id")
         return snapshot
 
-    def deserialize_statistics_snapshot(self, data: dict[str, t.Any]) -> models.StatisticsSnapshot:
-        """Deserializes the data into a statistics snapshot model.
-
-        Args:
-            data: The JSON payload.
-
-        Returns:
-            The requested model.
-        """
-        snapshot = models.StatisticsSnapshot()
-        snapshot.created_at = self._dt_from_iso_maybe(data["createdAt"])
-        snapshot.imported_at = self._dt_from_iso_maybe(data.get("importedAt"))
-        snapshot.data = self.deserialize_snapshot_data(data["data"])
-        self._set_attrs_cased(snapshot, data, "id", "player_id")
-        return snapshot
-
-    def gather(
-        self, serializer: t.Callable[[dict[str, t.Any]], T], data: list[dict[str, t.Any]]
-    ) -> list[T]:
-        """Calls the serializer on each mapping passed in.
-
-        Args:
-            serializer: The deserialization function to use.
-
-            data: The collection of items to deserialize.
-
-        Returns:
-            A list of the deserialized items.
-        """
-        return [serializer(item) for item in data]
-
     def deserialize_snapshot_data(self, data: dict[str, t.Any]) -> models.SnapshotData:
         """Deserializes the data into a snapshot data model.
 
@@ -212,18 +201,12 @@ class Serializer:
         Returns:
             The requested model.
         """
-        snapshot_data = models.SnapshotData()
-        snapshot_data.skills = self.gather(self.deserialize_skill, data["skills"].values())
-        snapshot_data.bosses = self.gather(self.deserialize_boss, data["bosses"].values())
-        snapshot_data.activities = self.gather(
-            self.deserialize_activity, data["activities"].values()
-        )
-
-        snapshot_data.computed = self.gather(
-            self.deserialize_computed_metric, data["computed"].values()
-        )
-
-        return snapshot_data
+        model = models.SnapshotData()
+        model.skills = self.__map(self.deserialize_skill, data["skills"].values())
+        model.bosses = self.__map(self.deserialize_boss, data["bosses"].values())
+        model.activities = self.__map(self.deserialize_activity, data["activities"].values())
+        model.computed = self.__map(self.deserialize_computed_metric, data["computed"].values())
+        return model
 
     def deserialize_skill(self, data: dict[str, t.Any]) -> models.Skill:
         """Deserializes the data into a skill model.
@@ -425,13 +408,10 @@ class Serializer:
             The requested model.
         """
         gains = models.PlayerGainsData()
-        gains.skills = self.gather(self.deserialize_skill_gains, data["skills"].values())
-        gains.bosses = self.gather(self.deserialize_boss_gains, data["bosses"].values())
-        gains.computed = self.gather(self.deserialize_computed_gains, data["computed"].values())
-        gains.activities = self.gather(
-            self.deserialize_activity_gains, data["activities"].values()
-        )
-
+        gains.skills = self.__map(self.deserialize_skill_gains, data["skills"].values())
+        gains.bosses = self.__map(self.deserialize_boss_gains, data["bosses"].values())
+        gains.computed = self.__map(self.deserialize_computed_gains, data["computed"].values())
+        gains.activities = self.__map(self.deserialize_activity_gains, data["activities"].values())
         return gains
 
     def deserialize_player_gains(self, data: dict[str, t.Any]) -> models.PlayerGains:
@@ -642,7 +622,7 @@ class Serializer:
         details = models.GroupDetail()
         details.verification_code = None
         details.group = self.deserialize_group(data)
-        details.memberships = self.gather(self.deserialize_group_membership, data["memberships"])
+        details.memberships = [self.deserialize_group_membership(m) for m in data["memberships"]]
         return details
 
     def deserialize_group_hiscores_activity_item(
@@ -734,7 +714,8 @@ class Serializer:
         """
         statistics = models.GroupStatistics()
         statistics.maxed_200ms_count = data["maxed200msCount"]
-        statistics.average_stats = self.deserialize_statistics_snapshot(data["averageStats"])
+        statistics.average_stats = self.deserialize_snapshot(data["averageStats"])
+        statistics.metric_leaders = self.deserialize_metric_leaders(data["metricLeaders"])
         self._set_attrs_cased(statistics, data, "maxed_total_count", "maxed_combat_count")
         return statistics
 
@@ -873,9 +854,9 @@ class Serializer:
         """
         details = models.CompetitionDetail()
         details.competition = self.deserialize_competition(data)
-        details.participations = self.gather(
-            self.deserialize_competition_participation_detail, data["participations"]
-        )
+        details.participations = [
+            self.deserialize_competition_participation_detail(d) for d in data["participations"]
+        ]
 
         return details
 
@@ -926,9 +907,9 @@ class Serializer:
         """
         progress = models.Top5ProgressResult()
         progress.player = self.deserialize_player(data["player"])
-        progress.history = self.gather(
-            self.deserialize_competition_history_data_point, data["history"]
-        )
+        progress.history = [
+            self.deserialize_competition_history_data_point(h) for h in data["history"]
+        ]
 
         return progress
 
@@ -947,8 +928,87 @@ class Serializer:
         model = models.CompetitionWithParticipations()
         model.verification_code = data.get("verificationCode")
         model.competition = self.deserialize_competition(data)
-        model.participations = self.gather(
-            self.deserialize_competition_participation, data["participations"]
-        )
+        model.participations = [
+            self.deserialize_competition_participation(p) for p in data["participations"]
+        ]
 
         return model
+
+    def deserialize_skill_leader(self, data: dict[str, t.Any]) -> models.SkillLeader:
+        """Deserializes the data into a skill leader model.
+
+        Args:
+            data: The JSON payload.
+
+        Returns:
+            The requested model.
+        """
+        leader = models.SkillLeader()
+        leader.metric = enums.Skills.from_str(data["metric"])
+        leader.player = self.deserialize_player(data["player"])
+        self._set_attrs(leader, data, "experience", "rank", "level")
+        return leader
+
+    def deserialize_boss_leader(self, data: dict[str, t.Any]) -> models.BossLeader:
+        """Deserializes the data into a boss leader model.
+
+        Args:
+            data: The JSON payload.
+
+        Returns:
+            The requested model.
+        """
+        leader = models.BossLeader()
+        leader.metric = enums.Bosses.from_str(data["metric"])
+        leader.player = self.deserialize_player(data["player"])
+        self._set_attrs(leader, data, "kills", "rank")
+        return leader
+
+    def deserialize_activity_leader(self, data: dict[str, t.Any]) -> models.ActivityLeader:
+        """Deserializes the data into an activity leader model.
+
+        Args:
+            data: The JSON payload.
+
+        Returns:
+            The requested model.
+        """
+        leader = models.ActivityLeader()
+        leader.metric = enums.Activities.from_str(data["metric"])
+        leader.player = self.deserialize_player(data["player"])
+        self._set_attrs(leader, data, "score", "rank")
+        return leader
+
+    def deserialize_computed_leader(self, data: dict[str, t.Any]) -> models.ComputedMetricLeader:
+        """Deserializes the data into a computed metric leader model.
+
+        Args:
+            data: The JSON payload.
+
+        Returns:
+            The requested model.
+        """
+        leader = models.ComputedMetricLeader()
+        leader.metric = enums.ComputedMetrics.from_str(data["metric"])
+        leader.player = self.deserialize_player(data["player"])
+        self._set_attrs(leader, data, "value", "rank")
+        return leader
+
+    def deserialize_metric_leaders(self, data: dict[str, t.Any]) -> models.MetricLeaders:
+        """Deserializes the data into a metric leaders model.
+
+        Args:
+            data: The JSON payload.
+
+        Returns:
+            The requested model.
+        """
+        leaders = models.MetricLeaders()
+        leaders.skills = self.__map(self.deserialize_skill_leader, data["skills"].values())
+        leaders.bosses = self.__map(self.deserialize_boss_leader, data["bosses"].values())
+        leaders.computed = self.__map(self.deserialize_computed_leader, data["computed"].values())
+        leaders.activities = self.__map(
+            self.deserialize_activity_leader, data["activities"].values()
+        )
+
+        return leaders
